# My First Agent

This is the "Hello World" agent!

## Description

This agent uses its primary skill, the `fetchai/echo` skill, to sends back the contents of any message it receives.

## Links

* <a href="https://docs.fetch.ai/aea/quickstart/" target="_blank">Quick Start</a>
* <a href="https://docs.fetch.ai/aea/build-aea-programmatically/" target="_blank">Programmatically Build an AEA</a>